#!/bin/bash
# 
# Aktualisiert die Version-Tags in .java-Dateien, die sich in dem
# angegebenen Verzeichnis und allen Unterverzeichnissen befinden.
#
# Ersetzt bspw. die folgenden Datumsangaben in einer .java-Datei:
#
# @version 17.04.2012
# @version 7.4.2012
# @version 17.04.12
# @version 7.4.12
#
# durch das aktuelle Datum oder den als Parameter uebergebenen Text.
#
# ACHTUNG: Es werden rekursiv _alle_ Unterverzeichnisse nach
# .java-Dateien durchsucht, um die Ersetzung vorzunehmen!
#
# woru, 26.04.2012
#

# variables
FILE_SUFFIX=".java"
CURRENT_DATE=`date +%d.%m.%Y`
NEW_VERSION=
USAGE="USAGE: $0 DIRECTORY [NEW_VERSION_TEXT]"

# check first parameter
if test -z "$1"; then
  echo $USAGE
  exit 1
else
  PARAM=$1
  # add "/" if not already ends with slash
  case "$PARAM" in
    *[^/] ) PARAM="$PARAM"/ ;;
  esac
fi

# check second parameter
if test -z "$2"; then
  NEW_VERSION=$CURRENT_DATE
else
  NEW_VERSION=$2
fi

# test for sed command
#sed 's/@version\s\+[0-9]\{1,2\}\.[0-9]\{1,2\}\.[0-9]\{2,4\}/@version test/g' Person.java

# alternative loop conditions
#for i in $( ls -ab $PARAM ); do      # problem if filename contains blanks
#ls -ab1 "$PARAM" | while read i; do  # really _all_ incl. hidden files

#go through all files of the current directory
for i in "$PARAM"*; do                # does not find hidden files
  # if file is not "." and file is not ".."
  if test "$i" != "." && test "$i" != ".."; then
    # if FILE_SUFFIX matches suffix of current file
    case "$i" in
      *"$FILE_SUFFIX" ) sed -e 's/@version\s\+[0-9]\{1,2\}\.[0-9]\{1,2\}\.[0-9]\{2,4\}/@version '${NEW_VERSION}'/g' "$i" > "$i"~~; if [ $? -ne 0 ]; then echo "substitution failed in $i" >&2; exit 1; fi; mv "$i" "$i"~; mv "$i"~~ "$i"; echo modified "$i";;
    esac
    # if current file is a directory
    if test -d "$i"; then
      # exclude directory 'material'
      if test "$i" != "$PARAM"material; then
        # run this script recursively
        /bin/bash "$0" "$i" "$2"
      fi
    fi
  fi
done

